#!/bin/bash
# 
# Welcome to the OurDelta bakery.
# 2008-11-01
# Peter Lieverdink <me@cafuego.net>
# Arjen Lentz <arjen@openquery.com.au>
#

# Should whine about packages this script depends on...
# they are not necessarily build-depends for upstream mysql.
# E.g: devscripts, fakeroot, bzr, readlink

# Exit immediately on any error
set -e

# Debug script and command lines
#set -x

BAKERY_BASE_DIR="$(dirname $(readlink -f ${0}))"
BUILD_BASE_DIR="$(pwd)/build-temp-$$"
DEB_POOL_BASE="/srv/shared/deb-pool"

export DEB_BUILD_OPTIONS="nocheck"

if [ ! $# -eq 1 ]; then
	echo "Usage: $0 [tarball]"
	echo "    tarball: source tarball"
	exit 1
else
	TARBALL="$(readlink -f ${1})"
fi

if [ ! -f ${TARBALL} ]; then
	echo "Can't find tarball: ${1}"
	exit 1
fi

# Determine source name
#
SOURCE_DIR=$(basename ${TARBALL} .tar.gz)

# Find major.minor version.
#
UPSTREAM="$(echo ${SOURCE_DIR} | cut -d- -f 2)"
MYVER="$(echo ${SOURCE_DIR} | cut -d- -f 2 | cut -d. -f1,2)"
RELEASE_EXTRA="$(echo ${SOURCE_DIR} | cut -d- -f 3-)"

pushd ${BAKERY_BASE_DIR}
cd ..
if [ ! -f .bzr-version ]; then
  echo "No bzr version info. You are not running this script from a"
  echo "properly exported bakery. Please do so. I will now quit."
  popd
  exit 1
else
  source .bzr-version
fi
popd

# Whatup?
#
echo "Going to build ${SOURCE_DIR} in ${BUILD_BASE_DIR}"

# Unpack tarball in our build base dir.
#
# test -d ${BUILD_BASE_DIR} && rm -fr ${BUILD_BASE_DIR}
echo "Unpacking tarball"
mkdir ${BUILD_BASE_DIR}
pushd ${BUILD_BASE_DIR}
tar xfz ${TARBALL}

# Copy the correct debian build script and patch tree from
# the bzr co we were invoked from. This way, versions always
# match this build script.
#
pushd "${BUILD_BASE_DIR}/${SOURCE_DIR}"
rm -rf ./debian
cp -r "${BAKERY_BASE_DIR}/debian-${MYVER}" debian

# Set version info (again)
#
if [ -e .ourdelta-version ]; then
  source .ourdelta-version
  PACKAGE_NAME=""
  VERSION="${UPSTREAM}"
  PATCHLEVEL="-d${PATCHLEVEL}"
  LOGSTRING="OurDelta patch set ${PATCHLEVEL} (including Sphinx storage engine)"
else
  if [ -e .mariadb-version ]; then
    source .mariadb-version
    PATCHLEVEL=""
    LOGSTRING="OurDelta build"
  else
    echo "no .ourdelta-version or .mariadb-version found in source tarball"
    exit 1
  fi
fi

# Clean up build file symlinks that are distro-specific. First remove all, then set
# new links.
DISTRODIRS="$(ls ./debian/dist)"
for distrodir in ${DISTRODIRS}; do
  DISTROFILES="$(ls ./debian/dist/${distrodir})"
  for distrofile in ${DISTROFILES}; do
    rm -f "./debian/${distrofile}";
  done;
done;

# Set no symlinks for build files in the debian dir, so we avoid adding AppArmor on Debian.
DISTRO="$(lsb_release -si)"
echo "Copying distribution specific build files for ${DISTRO}"
DISTROFILES="$(ls ./debian/dist/${DISTRO})"
for distrofile in ${DISTROFILES}; do
  rm -f "./debian/${distrofile}" && cp -a "./debian/dist/${DISTRO}/${distrofile}" "./debian/${distrofile}";
done;

# Adjust changelog, add new version.
#
echo "Incrementing changelog and starting build scripts"
CODENAME="$(lsb_release -sc)"
dch -b -D ${CODENAME} -v "${UPSTREAM}${PATCHLEVEL}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}${REPO_VERSION}" "Automatic build with ${LOGSTRING}."

echo "Creating package version ${UPSTREAM}${PATCHLEVEL}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}${REPO_VERSION} ... "

# Copy in up-to-date gpg keys
if [ -d /srv/shared/gnupg ]; then
  if [ ! -d ~/.gnupg.pre-ourdelta ]; then
    mv ~/.gnupg ~/.gnupg.pre-ourdelta
    mkdir ~/.gnupg
    cp /srv/shared/gnupg/* ~/.gnupg/
  fi
fi

# Fix author info, so we pick the right signing key.
#
REALNAME="$(getent passwd $LOGNAME | cut -d: -f5 | cut -d, -f1)"
USERHOST="$(whoami)@$(hostname)"
sed -i "s/${REALNAME} <${USERHOST}>/OurDelta Auto Signing Key <autosign@ourdelta.org>/" debian/changelog

# Build the package.
#
fakeroot dpkg-buildpackage

# Check if the local mirror deb-pool exists and move the results there.
# we have ourdelta, ourdelta-sail, and mariadb-ourdelta
POOL_DIR="${DEB_POOL_BASE}/${CODENAME}/${PACKAGE_NAME:+${PACKAGE_NAME}-}${RELEASE_NAME}{$RELEASE_EXTRA:-${RELEASE_EXTRA}}"
if [ -d "${POOL_DIR}" ]; then
    popd
    echo "Moving all built files to ${POOL_DIR}"
    mv *.{deb,dsc,changes,gz} "${POOL_DIR}"

# Cleanup
    popd
    rm -fr "${BUILD_BASE_DIR}"
else
    popd
    echo "Build complete ${BUILD_BASE_DIR}"

    popd
fi

# end of autobake script
